/*
Copyright © 2024 NAME HERE <EMAIL ADDRESS>
*/
package cmd

import (
	"fmt"
	"os"

	"git.andreafazzi.eu/andrea/probo/cmd/filter"
	"git.andreafazzi.eu/andrea/probo/cmd/util"

	tea "github.com/charmbracelet/bubbletea"
	"github.com/charmbracelet/lipgloss"
	"github.com/muesli/termenv"
	"github.com/spf13/cobra"
)

// filterCmd represents the filter command
var filterCmd = &cobra.Command{
	Use:   "filter",
	Short: "Create a new filter",
	Long:  "Create a new filter for selecting quizzes and participants",
	Run:   createFilter,
}

func init() {
	createCmd.AddCommand(filterCmd)

	filterCmd.Flags().StringP("type", "t", "participants", "Select the type of filter (participants or quizzes)")
}

func createFilter(cmd *cobra.Command, args []string) {
	f := util.LogToFile()
	if f != nil {
		defer f.Close()
	}

	path, err := cmd.Flags().GetString("input")
	if err != nil {
		panic(err)
	}

	filterType, err := cmd.Flags().GetString("type")
	if err != nil {
		panic(err)
	}

	lipgloss.SetColorProfile(termenv.TrueColor)

	model, err := tea.NewProgram(
		filter.New(path, filterType, util.ReadStdin()),
		tea.WithOutput(os.Stderr),
	).Run()
	if err != nil {
		fmt.Println("Error running program:", err)
		os.Exit(1)
	}
	result := model.(*filter.FilterModel)
	if result.Result != "" {
		fmt.Fprintf(os.Stdout, result.Result)
	}
}
